autoclose_flutter library

Classes

ClosableAnimationController
ClosableBoxPainter
ClosableChangeNotifier
ClosableDecorationImagePainter
ClosableGestureRecognizer
ClosableInkFeature
ClosableListenable
ClosableScrollDragController
ClosableTicker
ClosableWidgetsBinding
Closer
Contains collection of SingleAutoClosable and SubAutoClosable instances and handle their close with its own lifecycle period
GeneralCloser
A class that implements the common Closer logic and provides the capability to manage collections of SingleAutoClosable and SubAutoClosable instances.
HasCloser
to have ability to extend on GeneralCloser because dart mixins is not extendable
SingleAutoClosable<T>
Represents entities which able to (and should be) close This class descendant designed for the simple case of a single entity

Mixins

CloserWidgetState<T extends StatefulWidget>

Extensions

AnimationControllerClose on AnimationController
BoxPainterClose on BoxPainter
ChangeNotifierClose on ChangeNotifier
DecorationImagePainterClose on DecorationImagePainter
FutureClose on Future<T>
An extension on the Future class that allows you to manage its lifecycle with a HasCloser's Closer. This extension simplifies the process of adding a Future to a Closer while hiding the SingleAutoClosable implementation details.
GestureRecognizerClose on GestureRecognizer
HasCloserDoOnCloseExt on HasCloser
Adds custom actions to be executed when the associated Closer is closed.
InkFeatureClose on InkFeature
ListenableClose on Listenable
ScrollDragControllerClose on ScrollDragController
SubscriptionClose on StreamSubscription
An extension on the StreamSubscription class that allows you to manage its lifecycle with a HasCloser's Closer. This extension simplifies the process of adding a StreamSubscription to a Closer while hiding the SingleAutoClosable implementation details.
TickerClose on Ticker
TimerClose on Timer
An extension on the Timer class that allows you to manage its lifecycle with a HasCloser's Closer. This extension simplifies the process of adding a Timer to a Closer while hiding the SingleAutoClosable implementation details.
WidgetsBindingClose on WidgetsBinding